# metro-minify-esbuild

> Use [ESBuild](https://github.com/evanw/esbuild) to make your React Native code bundle faster.

Metro Bundler (used for React Native, Instagram, Internal Facebook) allows for any minifier you'd like. ESBuild is a very powerful transpiler / bundler -- but if you use it for transpilation then you can't use any babel plugins (like reanimated, decorators, strip flow types (required for React Native)). So a decent compromise is to use ESBuild for smaller tasks like minifying the output JavaScript bundle.

You write JavaScript -> Babel turns it into older JavaScript -> Minifier makes it small.

By default, Metro uses uglify-es, which currently produces the smallest bundles out of all popular minifiers, but it's ~46x slower than ESBuild.

> View [minifier benchmarks](https://github.com/privatenumber/minification-benchmarks).

## Usage

```
yarn add metro-minify-esbuild esbuild
```

Now set ESBuild with `transformer.minifierPath`, and pass in [`ESBuild` options](https://esbuild.github.io/api/#transform-api) via `transformer.minifierConfig`.

`metro.config.js`

```js
const { getDefaultConfig } = require("expo/metro-config");

const config = getDefaultConfig(__dirname);

config.transformer.minifierPath = "metro-minify-esbuild";
config.transformer.minifierConfig = {
  // ESBuild options...
};

module.exports = config;
```
